==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicFormattedTextFieldUI.h <==
// public class javax.swing.plaf.basic.BasicFormattedTextFieldUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class cb49ffe0ee4d13c javax_swing_plaf_TextUI
// @dep_class 5dd5aadd13fd56c3 javax_swing_plaf_basic_BasicFormattedTextFieldUI
// @dep_class c96b86492c177195 javax_swing_plaf_basic_BasicTextFieldUI
// @dep_class d214d118732d43a9 javax_swing_plaf_basic_BasicTextUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicTextFieldUI

#include "javax/swing/plaf/basic/BasicTextFieldUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicFormattedTextFieldUI_H_
#define _JC_javax_swing_plaf_basic_BasicFormattedTextFieldUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$sub_refs	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$refs	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$nonrefs	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$object	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vmethods	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vtable	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vtype	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$method$getPropertyPrefix$e7baa4035901c9a7(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$method_info$getPropertyPrefix$e7baa4035901c9a7;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vmethods {
	struct _jc_java_lang_String$object	*(*getPropertyPrefix$e7baa4035901c9a7)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_TextUI$vmethods	javax_swing_plaf_TextUI;
	_jc_javax_swing_plaf_basic_BasicTextUI$vmethods	javax_swing_plaf_basic_BasicTextUI;
	_jc_javax_swing_plaf_basic_BasicTextFieldUI$vmethods	javax_swing_plaf_basic_BasicTextFieldUI;
	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vmethods	javax_swing_plaf_basic_BasicFormattedTextFieldUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$refs {
    _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$sub_refs	javax_swing_plaf_basic_BasicFormattedTextFieldUI;
    _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_refs	javax_swing_plaf_basic_BasicTextFieldUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_refs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_TextUI$sub_refs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_TextUI$sub_nonrefs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextFieldUI;
    _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$sub_nonrefs	javax_swing_plaf_basic_BasicFormattedTextFieldUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$object {
	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vtype _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicFormattedTextFieldUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicFormattedTextFieldUI_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicFormattedTextFieldUI.h <==
// public class javax.swing.plaf.basic.BasicFormattedTextFieldUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class cb49ffe0ee4d13c javax_swing_plaf_TextUI
// @dep_class 5dd5aadd13fd56c3 javax_swing_plaf_basic_BasicFormattedTextFieldUI
// @dep_class c96b86492c177195 javax_swing_plaf_basic_BasicTextFieldUI
// @dep_class d214d118732d43a9 javax_swing_plaf_basic_BasicTextUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicTextFieldUI

#include "javax/swing/plaf/basic/BasicTextFieldUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicFormattedTextFieldUI_H_
#define _JC_javax_swing_plaf_basic_BasicFormattedTextFieldUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$sub_refs	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$refs	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$nonrefs	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$object	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vmethods	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vtable	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vtype	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$method$getPropertyPrefix$e7baa4035901c9a7(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$method_info$getPropertyPrefix$e7baa4035901c9a7;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vmethods {
	struct _jc_java_lang_String$object	*(*getPropertyPrefix$e7baa4035901c9a7)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_TextUI$vmethods	javax_swing_plaf_TextUI;
	_jc_javax_swing_plaf_basic_BasicTextUI$vmethods	javax_swing_plaf_basic_BasicTextUI;
	_jc_javax_swing_plaf_basic_BasicTextFieldUI$vmethods	javax_swing_plaf_basic_BasicTextFieldUI;
	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vmethods	javax_swing_plaf_basic_BasicFormattedTextFieldUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$refs {
    _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$sub_refs	javax_swing_plaf_basic_BasicFormattedTextFieldUI;
    _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_refs	javax_swing_plaf_basic_BasicTextFieldUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_refs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_TextUI$sub_refs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_TextUI$sub_nonrefs	javax_swing_plaf_TextUI;
    _jc_javax_swing_plaf_basic_BasicTextUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextUI;
    _jc_javax_swing_plaf_basic_BasicTextFieldUI$sub_nonrefs	javax_swing_plaf_basic_BasicTextFieldUI;
    _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$sub_nonrefs	javax_swing_plaf_basic_BasicFormattedTextFieldUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$object {
	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$vtype _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicFormattedTextFieldUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicFormattedTextFieldUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicFormattedTextFieldUI_H_ */
